@@ -1,8 +1,5 @@
-`catmap` <-
-function(dataset, ci, fe.forest, re.forest, printout, fe.sense, fe.senseplot, re.sense, re.senseplot, fe.cumulative, fe.cumplot, re.cumulative, re.cumplot, funnel){
-
+catmap<-function(dataset, ci, printout){
 options(warn=-1)
-
 data(catmapdata)
 
 #read in data from function
@@ -119,6 +116,7 @@ cat("\n")
 
 }
 
+studyname<-a1$name
 
 #print results to file dataset.output.txt
 
@@ -136,16 +134,20 @@ cat(results, sep="\n")
 sink()
 }
 
+return(comvarlogOR, combinedLogOR, combinedOR, combinedSeLogOR, weight, logOR, combinedVarLogOR, combinedChisq, combinedValue, combinedPvalue, lbci, ubci, combinedCI, SeLogOR, lbci.fe, ubci.fe, het.df, chisqHet, combinedHetValue, heterogeneityPvalue, tau2, weight.dsl, logOR.dsl, OR.dsl, seLogOR.dsl, varLogOR.dsl, lbci.dsl, ubci.dsl, ci.dsl, chisq.dsl, value.dsl, pvalue.dsl, studyname, a1, quantilenorm, ci, dataset)
+}
 
 #sensitivity analysis
 
+catmap.sense<-function(catmapobject, fe.sense, re.sense, fe.senseplot, re.senseplot){
+
 #fixed-effects sensitivity
 
 if (fe.sense==TRUE){
-sfplot<-matrix(0,nrow(a1),3)
-for(f in 1:nrow(a1)){
-sf.weight<-weight[-f]
-sf.logOR<-logOR[-f]
+sfplot<-matrix(0,nrow(catmapobject$a1),3)
+for(f in 1:nrow(catmapobject$a1)){
+sf.weight<-catmapobject$weight[-f]
+sf.logOR<-catmapobject$logOR[-f]
 
 sf.combinedLogOR<-((sum(sf.weight*sf.logOR))/sum(sf.weight))
 sf.combinedOR<-exp(sf.combinedLogOR)
@@ -156,7 +158,7 @@ sf.combinedValue<-pchisq(sf.combinedChisq, df=1)
 sf.combinedPvalue<-(1-sf.combinedValue)
 
 #get qnorm values
-alpha<-(1-((1-ci)/2))
+alpha<-(1-((1-catmapobject$ci)/2))
 quantilenorm<-qnorm(alpha, 0, 1)
 
 sf.lbci<-exp(sf.combinedLogOR-(quantilenorm*sf.combinedSeLogOR))
@@ -167,12 +169,12 @@ sf.lbci<-exp(sf.logOR-(quantilenorm*sf.SeLogOR))
 sf.ubci<-exp(sf.logOR+(quantilenorm*sf.SeLogOR))
 
 #calculate heterogeneity
-sf.df<-(nrow(a1)-2)
 sf.chisqHet<-(sum(sf.weight*(((sf.logOR-sf.combinedLogOR)^2))))
+sf.df<-(nrow(catmapobject$a1)-2)
 sf.combinedHetValue<-pchisq(sf.chisqHet, df=sf.df)
 sf.heterogeneityPvalue<-(1-sf.combinedHetValue)
 
-study.removed<-paste("Study Removed =", a1$name[f], sep=" ")
+study.removed<-paste("Study Removed =", catmapobject$studyname[f], sep=" ")
 sftable.header<-c("Inverse Variance Fixed-Effects OR", "Inverse Variance Fixed-Effects Lower Bound CI", "Inverse Variance Fixed-Effects Upper Bound CI", "Inverse Variance Fixed-Effects Chi-Square", "Inverse Variance Fixed-Effects p-value", "Q Statistic (Heterogeneity) Chi-Square", "Q Statistic (Heterogeneity) p-value")
 sftable.fill<-c(sf.combinedOR, sf.combinedCI, sf.combinedChisq, sf.combinedPvalue, sf.chisqHet, sf.heterogeneityPvalue)
 sf.results<-rbind(sftable.header, round(sftable.fill, digits=5))
@@ -184,15 +186,15 @@ cat("\n")
 
 #print results to file dataset.fixed.effects.sensitivity.txt
 
-if(dataset!=catmapdata){
-sink(paste(dataset, "fixed.effects.sensitivity.txt", sep="."), append=TRUE)
+if(catmapobject$dataset!=catmapdata){
+sink(paste(catmapobject$dataset, "fixed.effects.sensitivity.txt", sep="."), append=TRUE)
 cat("Fixed Effects Sensitivity Analysis\n")
 cat(study.removed, sf.results, sep="\n")
 cat("\n")
 sink()
 }
 
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 sink(paste("catmapdata", "fixed.effects.sensitivity.txt", sep="."), append=TRUE)
 cat("Fixed Effects Sensitivity Analysis\n")
 cat(study.removed, sf.results, sep="\n")
@@ -204,12 +206,12 @@ sink()
 
 #random-effects sensitivity
 
-if (re.sense==TRUE & tau2 > 0){
-srplot<-matrix(0,nrow(a1),3)
-for(r in 1:nrow(a1)){
-sr.weight<-weight[-r]
-sr.logOR<-logOR[-r]
-sr.comvarlogOR<-comvarlogOR[-r]
+if (re.sense==TRUE & catmapobject$tau2 > 0){
+srplot<-matrix(0,nrow(catmapobject$a1),3)
+for(r in 1:nrow(catmapobject$a1)){
+sr.weight<-catmapobject$weight[-r]
+sr.logOR<-catmapobject$logOR[-r]
+sr.comvarlogOR<- catmapobject$comvarlogOR[-r]
 
 sr.combinedLogOR<-((sum(sr.weight*sr.logOR))/sum(sr.weight))
 sr.combinedOR<-exp(sr.combinedLogOR)
@@ -220,7 +222,7 @@ sr.combinedValue<-pchisq(sr.combinedChisq, df=1)
 sr.combinedPvalue<-(1-sr.combinedValue)
 
 #get qnorm values
-alpha<-(1-((1-ci)/2))
+alpha<-(1-((1-catmapobject$ci)/2))
 quantilenorm<-qnorm(alpha, 0, 1)
 
 sr.lbci<-exp(sr.combinedLogOR-(quantilenorm*sr.combinedSeLogOR))
@@ -231,7 +233,7 @@ sr.lbci<-exp(sr.logOR-(quantilenorm*sr.SeLogOR))
 sr.ubci<-exp(sr.logOR+(quantilenorm*sr.SeLogOR))
 
 #calculate heterogeneity
-sr.df<-(nrow(a1)-2)
+sr.df<-(nrow(catmapobject$a1)-2)
 sr.chisqHet<-(sum(sr.weight*(((sr.logOR-sr.combinedLogOR)^2))))
 sr.combinedHetValue<-pchisq(sr.chisqHet, df=sr.df)
 sr.heterogeneityPvalue<-(1-sr.combinedHetValue)
@@ -254,7 +256,7 @@ srvalue.dsl<-pchisq(srchisq.dsl, df=1)
 srpvalue.dsl<-(1-srvalue.dsl)
 }
 
-srstudy.removed<-paste("Study Removed =", a1$name[r], sep=" ")
+srstudy.removed<-paste("Study Removed =", catmapobject$studyname[r], sep=" ")
 srtable.header<-c("Q Statistic (Heterogeneity) Chi-Square", "Q Statistic (Heterogeneity) p-value", "DerSimonian & Laird Random-Effects OR", "DerSimonian & Laird Random-Effects Lower Bound CI", "DerSimonian & Laird Random-Effects Chi-Square", "DerSimonian & Laird Random-Effects p-value")
 srtable.fill<-c(sr.chisqHet, sr.heterogeneityPvalue, srOR.dsl, srci.dsl, srpvalue.dsl)
 sr.results<-rbind(srtable.header, round(srtable.fill, digits=5))
@@ -266,15 +268,15 @@ cat("\n")
 
 #print results to file dataset.random.effects.sensitivity.txt
 
-if(dataset!=catmapdata){
-sink(paste(dataset, "random.effects.sensitivity.txt", sep="."), append=TRUE)
+if(catmapobject$dataset!=catmapdata){
+sink(paste(catmapobject$dataset, "random.effects.sensitivity.txt", sep="."), append=TRUE)
 cat("Random Effects Sensitivity Analysis\n")
 cat(srstudy.removed, sr.results, sep="\n")
 cat("\n")
 sink()
 }
 
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 sink(paste("catmapdata", "random.effects.sensitivity.txt", sep="."), append=TRUE)
 cat("Random Effects Sensitivity Analysis\n")
 cat(srstudy.removed, sr.results, sep="\n")
@@ -284,14 +286,92 @@ sink()
 }
 }
 
+ci100<- catmapobject$ci*100
+
+#create fixed-effects sensitivity plots
+if (fe.senseplot==TRUE){
+if(catmapobject$dataset!=catmapdata){
+pdf(file=(paste(catmapobject$dataset, "fixed.effects.sensitivity.plot.pdf", sep=".")))
+}
+if(catmapobject$dataset==catmapdata){
+pdf(file=(paste("catmapdata", "fixed.effects.sensitivity.plot.pdf", sep=".")))
+}
+sfpstudy<-c(1:nrow(catmapobject$a1))
+sfplx<-max((min(sfplot[,2])-0.25),0)
+sfphx<-max(sfplot[,3])+0.25
+sfply<-min(sfpstudy)-0.5
+sfphy<-max(sfpstudy)+0.5
+mar1<-c(5.1, 7.1, 4.1, 2.1)
+las1<-1
+par("las"=las1)
+par("mar"=mar1)
+sfpdummy<-c(rep(NA, length(sfpstudy)))
+sfpdummy[1]<- sfphx
+sfpdummy[2]<- sfplx
+sfpydummy<-c(rep(NA, length(sfpstudy)))
+sfpydummy[1]<- sfphy
+sfpydummy[2]<- sfply
+xtitle<-paste("OR(", ci100, "% CI)")
+plot(sfpdummy, sfpydummy, type="n", log="x", ylab="", ylim=rev(c(sfply, sfphy)), yaxt="n", xlab=xtitle, main="Sensitivity Analysis: \n Inverse Variance (Fixed-Effects) ORs")
+abline(v=1.0)
+for(z in 1:nrow(catmapobject$a1)){
+points(sfplot[z,1],sfpstudy[z], pch=22, bg="black", col="black")
+segments(sfplot[z,2],sfpstudy[z],sfplot[z,3],sfpstudy[z], bg="black", col="black")
+sfpstudyname<-paste("Study Removed:", catmapobject$studyname[z], sep="\n")
+mtext(paste(sfpstudyname),side=2, at=sfpstudy[z], cex=0.80)
+}
+dev.off()
+}
+
+ci100<- catmapobject$ci*100
+
+#create random-effects sensitivity plots
+if (re.senseplot==TRUE & catmapobject$tau2 > 0){
+if(catmapobject$dataset!=catmapdata){
+pdf(file=(paste(catmapobject$dataset, "random.effects.sensitivity.plot.pdf", sep=".")))
+}
+if(catmapobject$dataset==catmapdata){
+pdf(file=(paste("catmapdata", "random.effects.sensitivity.plot.pdf", sep=".")))
+}
+srpstudy<-c(1:nrow(catmapobject$a1))
+srplx<-max((min(srplot[,2])-0.25),0)
+srphx<-max(srplot[,3])+0.25
+srply<-min(srpstudy)-0.5
+srphy<-max(srpstudy)+0.5
+mar1<-c(5.1, 7.1, 4.1, 2.1)
+las1<-1
+par("las"=las1)
+par("mar"=mar1)
+srpdummy<-c(rep(NA, length(srpstudy)))
+srpdummy[1]<- srphx
+srpdummy[2]<- srplx
+srpydummy<-c(rep(NA, length(srpstudy)))
+srpydummy[1]<- srphy
+srpydummy[2]<- srply
+xtitle<-paste("OR(", ci100, "% CI)")
+plot(srpdummy, srpydummy, type="n", log="x", ylab="", ylim=rev(c(srply, srphy)), yaxt="n", xlab=xtitle, main="Sensitivity Analysis: \n DerSimonian & Laird (Random-Effects) ORs")
+abline(v=1.0)
+for(y in 1:nrow(catmapobject$a1)){
+points(srplot[y,1],srpstudy[y], pch=22, bg="black", col="black")
+segments(srplot[y,2],srpstudy[y],srplot[y,3],srpstudy[y], bg="black", col="black")
+srpstudyname<-paste("Study Removed:", catmapobject$studyname[y], sep="\n")
+mtext(paste(srpstudyname),side=2, at=srpstudy[y], cex=0.80)
+}
+#dev.off()
+}
+}
+
+catmap.cumulative<-function(catmapobject, fe.cumulative, fe.cumplot, re.cumulative, re.cumplot){
+
 #fixed-effect cumulative meta analyses
+ci100<- catmapobject$ci*100
 
 if (fe.cumulative==TRUE){
 
-cfplot<-matrix(0, nrow(a1),3)
-for(c in 1:nrow(a1)){
-cf.weight<-weight[1:c]
-cf.logOR<-logOR[1:c]
+cfplot<-matrix(0, nrow(catmapobject$a1),3)
+for(c in 1:nrow(catmapobject$a1)){
+cf.weight<- catmapobject$weight[1:c]
+cf.logOR<- catmapobject$logOR[1:c]
 
 cf.combinedLogOR<-((sum(cf.weight*cf.logOR))/sum(cf.weight))
 cf.combinedOR<-exp(cf.combinedLogOR)
@@ -302,7 +382,7 @@ cf.combinedValue<-pchisq(cf.combinedChisq, df=1)
 cf.combinedPvalue<-(1-cf.combinedValue)
 
 #get qnorm values
-alpha<-(1-((1-ci)/2))
+alpha<-(1-((1-catmapobject$ci)/2))
 quantilenorm<-qnorm(alpha, 0, 1)
 
 cf.lbci<-exp(cf.combinedLogOR-(quantilenorm*cf.combinedSeLogOR))
@@ -318,7 +398,7 @@ cf.chisqHet<-(sum(cf.weight*(((cf.logOR-cf.combinedLogOR)^2))))
 cf.combinedHetValue<-pchisq(cf.chisqHet, df=cf.df)
 cf.heterogeneityPvalue<-(1-cf.combinedHetValue)
 
-study.added<-paste("Study Added =", a1$name[c], sep=" ")
+study.added<-paste("Study Added =", catmapobject$studyname[c], sep=" ")
 cftable.header<-c("Inverse Variance Fixed-Effects OR", "Inverse Variance Fixed-Effects Lower Bound CI", "Inverse Variance Fixed-Effects Upper Bound CI", "Inverse Variance Fixed-Effects Chi-Square", "Inverse Variance Fixed-Effects p-value", "Q Statistic (Heterogeneity) Chi-Square", "Q Statistic (Heterogeneity) p-value")
 cftable.fill<-c(cf.combinedOR, cf.combinedCI, cf.combinedChisq, cf.combinedPvalue, cf.chisqHet, cf.heterogeneityPvalue)
 cf.results<-rbind(cftable.header, round(cftable.fill, digits=5))
@@ -330,15 +410,15 @@ cat("\n")
 
 #print results to file dataset.fixed.effects.cumulative.txt
 
-if(dataset!=catmapdata){
-sink(paste(dataset, "fixed.effects.cumulative.txt", sep="."), append=TRUE)
+if(catmapobject$dataset!=catmapdata){
+sink(paste(catmapobject$dataset, "fixed.effects.cumulative.txt", sep="."), append=TRUE)
 cat("Fixed Effects Cumulative Meta-Analysis\n")
 cat(study.added, cf.results, sep="\n")
 cat("\n")
 sink()
 }
 
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 sink(paste("catmapdata", "fixed.effects.cumulative.txt", sep="."), append=TRUE)
 cat("Fixed Effects Cumulative Meta-Analysis\n")
 cat(study.added, cf.results, sep="\n")
@@ -350,13 +430,13 @@ sink()
 
 #random-effect cumulative meta analyses
 
-if (re.cumulative==TRUE & tau2 > 0){
-crplot<-matrix(0,(nrow(a1)-1),3)
-for(u in 2:nrow(a1)){
+if (re.cumulative==TRUE & catmapobject$tau2 > 0){
+crplot<-matrix(0,(nrow(catmapobject$a1)-1),3)
+for(u in 2:nrow(catmapobject$a1)){
 v<-u-1
-cr.weight<-weight[1:u]
-cr.logOR<-logOR[1:u]
-cr.comvarlogOR<-comvarlogOR[1:u]
+cr.weight<- catmapobject$weight[1:u]
+cr.logOR<- catmapobject$logOR[1:u]
+cr.comvarlogOR<- catmapobject$comvarlogOR[1:u]
 
 cr.combinedLogOR<-((sum(cr.weight*cr.logOR))/sum(cr.weight))
 cr.combinedOR<-exp(cr.combinedLogOR)
@@ -367,7 +447,7 @@ cr.combinedValue<-pchisq(cr.combinedChisq, df=1)
 cr.combinedPvalue<-(1-cr.combinedValue)
 
 #get qnorm values
-alpha<-(1-((1-ci)/2))
+alpha<-(1-((1- catmapobject$ci)/2))
 quantilenorm<-qnorm(alpha, 0, 1)
 
 cr.lbci<-exp(cr.combinedLogOR-(quantilenorm*cr.combinedSeLogOR))
@@ -401,7 +481,7 @@ crvalue.dsl<-pchisq(crchisq.dsl, df=1)
 crpvalue.dsl<-(1-crvalue.dsl)
 }
 
-crstudy.added<-paste("Study Added =", a1$name[u], sep=" ")
+crstudy.added<-paste("Study Added =", catmapobject$studyname[u], sep=" ")
 crtable.header<-c("Q Statistic (Heterogeneity) Chi-Square", "Q Statistic (Heterogeneity) p-value", "DerSimonian & Laird Random-Effects OR", "DerSimonian & Laird Random-Effects Lower Bound CI", "DerSimonian & Laird Random-Effects Chi-Square", "DerSimonian & Laird Random-Effects p-value")
 crtable.fill<-c(cr.chisqHet, cr.heterogeneityPvalue, crOR.dsl, crci.dsl, crpvalue.dsl)
 cr.results<-rbind(crtable.header, round(crtable.fill, digits=5))
@@ -413,15 +493,15 @@ cat("\n")
 
 #print results to file dataset.random.effects.cumulative.txt
 
-if(dataset!=catmapdata){
-sink(paste(dataset, "random.effects.cumulative.txt", sep="."), append=TRUE)
+if(catmapobject$dataset!=catmapdata){
+sink(paste(catmapobject$dataset, "random.effects.cumulative.txt", sep="."), append=TRUE)
 cat("Random Effects Cumulative Meta-Analysis\n")
 cat(crstudy.added, cr.results, sep="\n")
 cat("\n")
 sink()
 }
 
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 sink(paste("catmapdata", "random.effects.cumulative.txt", sep="."), append=TRUE)
 cat("Random Effects Cumulative Meta-Analysis\n")
 cat(crstudy.added, cr.results, sep="\n")
@@ -431,90 +511,18 @@ sink()
 }
 }
 
-ci100<-ci*100
-
-#create fixed-effects sensitivity plots
-if (fe.senseplot==TRUE){
-if(dataset!=catmapdata){
-pdf(file=(paste(dataset, "fixed.effects.sensitivity.plot.pdf", sep=".")))
-}
-if(dataset==catmapdata){
-pdf(file=(paste("catmapdata", "fixed.effects.sensitivity.plot.pdf", sep=".")))
-}
-sfpstudy<-c(1:nrow(a1))
-sfplx<-max((min(sfplot[,2])-0.25),0)
-sfphx<-max(sfplot[,3])+0.25
-sfply<-min(sfpstudy)-0.5
-sfphy<-max(sfpstudy)+0.5
-mar1<-c(5.1, 7.1, 4.1, 2.1)
-las1<-1
-par("las"=las1)
-par("mar"=mar1)
-sfpdummy<-c(rep(NA, length(sfpstudy)))
-sfpdummy[1]<- sfphx
-sfpdummy[2]<- sfplx
-sfpydummy<-c(rep(NA, length(sfpstudy)))
-sfpydummy[1]<- sfphy
-sfpydummy[2]<- sfply
-xtitle<-paste("OR (", ci100, "% CI)")
-plot(sfpdummy, sfpydummy, type="n", log="x", ylab="", ylim=rev(c(sfply, sfphy)), yaxt="n", xlab=xtitle, main="Sensitivity Analysis: \n Inverse Variance (Fixed-Effects) ORs")
-abline(v=1.0)
-for(z in 1:nrow(a1)){
-points(sfplot[z,1],sfpstudy[z], pch=22, bg="black", col="black")
-segments(sfplot[z,2],sfpstudy[z],sfplot[z,3],sfpstudy[z], bg="black", col="black")
-sfpstudyname<-paste("Study Removed:",a1$name[z], sep="\n")
-mtext(paste(sfpstudyname),side=2, at=sfpstudy[z], cex=0.80)
-}
-dev.off()
-}
-
-#create random-effects sensitivity plots
-if (re.senseplot==TRUE & tau2 > 0){
-if(dataset!=catmapdata){
-pdf(file=(paste(dataset, "random.effects.sensitivity.plot.pdf", sep=".")))
-}
-if(dataset==catmapdata){
-pdf(file=(paste("catmapdata", "random.effects.sensitivity.plot.pdf", sep=".")))
-}
-srpstudy<-c(1:nrow(a1))
-srplx<-max((min(srplot[,2])-0.25),0)
-srphx<-max(srplot[,3])+0.25
-srply<-min(srpstudy)-0.5
-srphy<-max(srpstudy)+0.5
-mar1<-c(5.1, 7.1, 4.1, 2.1)
-las1<-1
-par("las"=las1)
-par("mar"=mar1)
-srpdummy<-c(rep(NA, length(srpstudy)))
-srpdummy[1]<- srphx
-srpdummy[2]<- srplx
-srpydummy<-c(rep(NA, length(srpstudy)))
-srpydummy[1]<- srphy
-srpydummy[2]<- srply
-xtitle<-paste("OR (", ci100, "% CI)")
-plot(srpdummy, srpydummy, type="n", log="x", ylab="", ylim=rev(c(srply, srphy)), yaxt="n", xlab=xtitle, main="Sensitivity Analysis: \n DerSimonian & Laird (Random-Effects) ORs")
-abline(v=1.0)
-for(y in 1:nrow(a1)){
-points(srplot[y,1],srpstudy[y], pch=22, bg="black", col="black")
-segments(srplot[y,2],srpstudy[y],srplot[y,3],srpstudy[y], bg="black", col="black")
-srpstudyname<-paste("Study Removed:", a1$name[y], sep="\n")
-mtext(paste(srpstudyname),side=2, at=srpstudy[y], cex=0.80)
-}
-dev.off()
-}
-
 #create fixed-effects cumulative plots
 if (fe.cumplot==TRUE){
-if(dataset!=catmapdata){
-pdf(file=(paste(dataset, "fixed.effects.cumulative.plot.pdf", sep=".")))
+if(catmapobject$dataset!=catmapdata){
+pdf(file=(paste(catmapobject$dataset, "fixed.effects.cumulative.plot.pdf", sep=".")))
 }
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 pdf(file=(paste("catmapdata", "fixed.effects.cumulative.plot.pdf", sep=".")))
 }
-cfpstudy<-c(1:nrow(a1))
+cfpstudy<-c(1:nrow(catmapobject$a1))
 cfplx<-max((min(cfplot[,2])-0.25),0)
 cfphx<-max(cfplot[,3])+0.25
-cfply<-min(cfpstudy)-0.5
+cfply<-1-0.5
 cfphy<-max(cfpstudy)+0.5
 mar1<-c(5.1, 7.1, 4.1, 2.1)
 las1<-1
@@ -526,27 +534,27 @@ cfpdummy[2]<- cfplx
 cfpydummy<-c(rep(NA, length(cfpstudy)))
 cfpydummy[1]<- cfphy
 cfpydummy[2]<- cfply
-xtitle<-paste("OR (", ci100, "% CI)")
+xtitle<-paste("OR(", ci100, "% CI)")
 plot(cfpdummy, cfpydummy, type="n", log="x", ylab="", ylim=rev(c(cfply, cfphy)), yaxt="n", xlab=xtitle, main="Cumulative Meta-Analysis: \n Inverse Variance (Fixed-Effects) ORs")
 abline(v=1.0)
-for(x in 1:nrow(a1)){
+for(x in 1:nrow(catmapobject$a1)){
 points(cfplot[x,1],cfpstudy[x], pch=22, bg="black", col="black")
 segments(cfplot[x,2],cfpstudy[x],cfplot[x,3],cfpstudy[x], bg="black", col="black")
-cfpstudyname<-paste("Study Added:", a1$name[x], sep="\n")
+cfpstudyname<-paste("Study Added:", catmapobject$studyname[x], sep="\n")
 mtext(paste(cfpstudyname),side=2, at=cfpstudy[x], cex=0.80)
 }
 dev.off()
 }
 
 #create random-effects cumulative plots
-if (re.cumplot==TRUE & tau2 > 0){
-if(dataset!=catmapdata){
-pdf(file=(paste(dataset, "random.effects.cumulative.plot.pdf", sep=".")))
+if (re.cumplot==TRUE & catmapobject$tau2 > 0){
+if(catmapobject$dataset!=catmapdata){
+pdf(file=(paste(catmapobject$dataset, "random.effects.cumulative.plot.pdf", sep=".")))
 }
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 pdf(file=(paste("catmapdata", "random.effects.cumulative.plot.pdf", sep=".")))
 }
-crpstudy<-c(1:(nrow(a1)-1))
+crpstudy<-c(1:(nrow(catmapobject$a1)-1))
 crplx<-max((min(crplot[,2])-0.25),0)
 crphx<-max(crplot[,3])+0.25
 crply<-min(crpstudy)-0.5
@@ -564,75 +572,78 @@ crpydummy[2]<- crply
 xtitle<-paste("OR (", ci100, "% CI)")
 plot(crpdummy, crpydummy, type="n", log="x", ylab="", ylim=rev(c(crply, crphy)), yaxt="n", xlab=xtitle, main="Cumulative Meta-Analysis: \n DerSimonian & Laird (Random-Effects) ORs")
 abline(v=1.0)
-for(w in 1:(nrow(a1)-1)){
+for(w in 1:(nrow(catmapobject$a1)-1)){
 q<-w+1
 points(crplot[w,1],crpstudy[w], pch=22, bg="black", col="black")
 segments(crplot[w,2],crpstudy[w],crplot[w,3],crpstudy[w], bg="black", col="black")
-crpstudyname<-paste("Study Added:", a1$name[w], sep="\n")
+crpstudyname<-paste("Study Added:", catmapobject$studyname[w], sep="\n")
 mtext(paste(crpstudyname),side=2, at=crpstudy[w], cex=0.80)
 }
-dev.off()
+#dev.off()
+}
 }
-
 
 # create fixed-effect forest plots
 
+catmap.forest<-function(catmapobject, fe.forest, re.forest){
+ci100<- catmapobject$ci*100
 if (fe.forest==TRUE){
-if(dataset!=catmapdata){
-pdf(file=(paste(dataset, "fixed.effects.plot.pdf", sep=".")))
+if(catmapobject$dataset!=catmapdata){
+pdf(file=(paste(catmapobject$dataset, "fixed.effects.plot.pdf", sep=".")))
 }
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 pdf(file=(paste("catmapdata", "fixed.effects.plot.pdf", sep=".")))
 }
-prop.weight<-(weight/(sum(weight))*10)
-OR<-c(combinedOR, exp(logOR))
-study<-1:(nrow(a1)+1)
-lx<-max((min(lbci.fe)-0.25),0)
-hx<-max(ubci.fe)+0.25
-ly<-min(study)-0.5
-hy<-max(study)+0.5
+prop.weight<-(catmapobject$weight/(sum(catmapobject$weight))*10)
+OR<-c(catmapobject$combinedOR, exp(catmapobject$logOR))
+study<-1:(nrow(catmapobject$a1)+1)
+lx<-max((min(catmapobject$lbci.fe)-0.25),0)
+hx<-max(catmapobject$ubci.fe)+0.25
+ly<-(1-0.5)
+hy<-(length(catmapobject$study)+ 1.5)
 mar1<-c(5.1, 7.1, 4.1, 2.1)
 las1<-1
 par("las"=las1)
 par("mar"=mar1)
-dummy<-c(rep(NA, length(study)))
+dummy<-c(rep(NA, length(catmapobject$study)))
 dummy[1]<-hx
 dummy[2]<-lx
-ydummy<-c(rep(NA, length(study)))
+ydummy<-c(rep(NA, length(catmapobject$study)))
 ydummy[1]<-hy
 ydummy[2]<-ly
-xtitle<-paste("OR (", ci100, "% CI)")
+xtitle<-paste("OR(", ci100, "% CI)")
 plot(dummy, ydummy, type="n", log="x", ylab="", yaxt="n", xlab=xtitle, main="Inverse Variance (Fixed-Effects) ORs")
-points(OR[1], study[1], pch=22, cex=1.0, bg="red", col="red")
-segments(lbci, 1, ubci, 1, col="red")
+points(OR[1], 1, pch=22, cex=1.0, bg="red", col="red")
+segments(catmapobject$lbci, 1, catmapobject$ubci, 1, col="red")
 mtext("Pooled OR",side=2,at=1, cex=0.80)
 abline(v=1.0)
-for(i in 2:(nrow(a1)+1)){
+limit<-nrow(catmapobject$a1)+1
+counts<-c(1:limit)
+for(i in 2:(nrow(catmapobject$a1)+1)){
 j<-i-1
-points(OR[i],study[i], pch=22, cex=prop.weight[j], bg="black", col="black")
-segments(lbci.fe[j],study[i],ubci.fe[j],study[i], bg="black", col="black")
-studyname<-a1$name[j]
-mtext(paste(studyname),side=2, at=study[i], cex=0.80)
+points(OR[i], counts[i], pch=22, cex=prop.weight[j], bg="black", col="black")
+segments(catmapobject$lbci.fe[j], counts[i], catmapobject$ubci.fe[j], counts[i], bg="black", col="black")
+mtext(paste(catmapobject$studyname[j]),side=2, at=counts[i], cex=0.80)
 }
 dev.off()
 }
 
 #create random-effects forest plots 
 
-if (re.forest==TRUE & tau2 > 0){
-if(dataset!=catmapdata){
-pdf(file=(paste(dataset, "random.effects.plot.pdf", sep=".")))
+if (re.forest==TRUE & catmapobject$tau2 > 0){
+if(catmapobject$dataset!=catmapdata){
+pdf(file=(paste(catmapobject$dataset, "random.effects.plot.pdf", sep=".")))
 }
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 pdf(file=(paste("catmapdata", "random.effects.plot.pdf", sep=".")))
 }
-dslprop.weight<-(weight.dsl/(sum(weight.dsl))*100)
-dslOR<-c(OR.dsl, exp(logOR))
-rstudy<-1:(nrow(a1)+1)
-rlx<-max((min(lbci.fe)-0.25),0)
-rhx<-max(ubci.fe)+0.25
-rly<-min(study)-0.5
-rhy<-max(study)+0.5
+dslprop.weight<-(catmapobject$weight.dsl/(sum(catmapobject$weight.dsl))*100)
+dslOR<-c(catmapobject$OR.dsl, exp(catmapobject$logOR))
+rstudy<-1:(nrow(catmapobject$a1)+1)
+rlx<-max((min(catmapobject$lbci.fe)-0.25),0)
+rhx<-max(catmapobject$ubci.fe)+0.25
+rly<-(1-0.5)
+rhy<-(length(catmapobject$study)+1.5)
 mar1<-c(5.1, 7.1, 4.1, 2.1)
 las1<-1
 par("las"=las1)
@@ -643,37 +654,41 @@ rdummy[2]<-rlx
 rydummy<-c(rep(NA, length(rstudy)))
 rydummy[1]<-rhy
 rydummy[2]<-rly
-xtitle<-paste("OR (", ci100, "% CI)")
+xtitle<-paste("OR(", ci100, "% CI)")
 plot(rdummy, rydummy, type="n", log="x", ylab="", yaxt="n", xlab=xtitle, main="DerSimonian & Laird (Random-Effects) ORs")
-points(dslOR[1], study[1], pch=22, cex=1.0, bg="red", col="red")
-segments(lbci.dsl, 1, ubci.dsl, 1, col="red")
+points(dslOR[1], 1, pch=22, cex=1.0, bg="red", col="red")
+segments(catmapobject$lbci.dsl, 1, catmapobject$ubci.dsl, 1, col="red")
 mtext("Pooled OR",side=2,at=1, cex=0.80)
 abline(v=1.0)
-for(i in 2:(nrow(a1)+1)){
+limit<-nrow(catmapobject$a1)+1
+counts<-c(1:limit)
+for(i in 2:(nrow(catmapobject$a1)+1)){
 j<-i-1
-points(OR[i],study[i], pch=22, cex=prop.weight[j], bg="black", col="black")
-segments(lbci.fe[j],study[i],ubci.fe[j],study[i], bg="black", col="black")
-studyname<-a1$name[j]
-mtext(paste(studyname),side=2, at=study[i], cex=0.80)
+points(OR[i],counts[i], pch=22, cex=prop.weight[j], bg="black", col="black")
+segments(catmapobject$lbci.fe[j],counts[i], catmapobject$ubci.fe[j],counts[i], bg="black", col="black")
+mtext(paste(catmapobject$studyname[j]),side=2, at=counts[i], cex=0.80)
 }
-dev.off()
+#dev.off()
 }
+}
 
 #funnel plot
 
+catmap.funnel<-function(catmapobject, funnel){
 if(funnel==TRUE){
-if(dataset!=catmapdata){
-pdf(file=(paste(dataset, "funnel.plot.pdf", sep=".")))
+if(catmapobject$dataset!=catmapdata){
+pdf(file=(paste(catmapobject$dataset, "funnel.plot.pdf", sep=".")))
 }
-if(dataset==catmapdata){
+if(catmapobject$dataset==catmapdata){
 pdf(file=(paste("catmapdata", "funnel.plot.pdf", sep=".")))
 }
-OddsRatio<-exp(logOR)
-maxse<-max(seLogOR)
-minse<-min(seLogOR)
-plot(OddsRatio, seLogOR, ylim=rev(c(minse,maxse)),log="x")
+OddsRatio<-exp(catmapobject$logOR)
+fun.se<-sqrt(catmapobject$comvarlogOR)
+maxse<-max(fun.se)
+minse<-min(fun.se)
+plot(OddsRatio, fun.se, ylim=rev(c(minse,maxse)),log="x", ylab="Standard Error Log OR")
 abline(v=1)
-abline(v=combinedOR, lty=2)
+abline(v=catmapobject$combinedOR, lty=2)
 #dev.off()
 }
 }
